pitchtools.Set
==============

.. abjad-lineage:: abjad.tools.pitchtools.Set.Set.Set

.. autoclass:: abjad.tools.pitchtools.Set.Set.Set

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.Set.Set.Set.copy
      ~abjad.tools.pitchtools.Set.Set.Set.difference
      ~abjad.tools.pitchtools.Set.Set.Set.from_selection
      ~abjad.tools.pitchtools.Set.Set.Set.intersection
      ~abjad.tools.pitchtools.Set.Set.Set.isdisjoint
      ~abjad.tools.pitchtools.Set.Set.Set.issubset
      ~abjad.tools.pitchtools.Set.Set.Set.issuperset
      ~abjad.tools.pitchtools.Set.Set.Set.item_class
      ~abjad.tools.pitchtools.Set.Set.Set.name
      ~abjad.tools.pitchtools.Set.Set.Set.new
      ~abjad.tools.pitchtools.Set.Set.Set.storage_format
      ~abjad.tools.pitchtools.Set.Set.Set.symmetric_difference
      ~abjad.tools.pitchtools.Set.Set.Set.union
      ~abjad.tools.pitchtools.Set.Set.Set.__and__
      ~abjad.tools.pitchtools.Set.Set.Set.__contains__
      ~abjad.tools.pitchtools.Set.Set.Set.__eq__
      ~abjad.tools.pitchtools.Set.Set.Set.__ge__
      ~abjad.tools.pitchtools.Set.Set.Set.__gt__
      ~abjad.tools.pitchtools.Set.Set.Set.__hash__
      ~abjad.tools.pitchtools.Set.Set.Set.__iter__
      ~abjad.tools.pitchtools.Set.Set.Set.__le__
      ~abjad.tools.pitchtools.Set.Set.Set.__len__
      ~abjad.tools.pitchtools.Set.Set.Set.__lt__
      ~abjad.tools.pitchtools.Set.Set.Set.__ne__
      ~abjad.tools.pitchtools.Set.Set.Set.__or__
      ~abjad.tools.pitchtools.Set.Set.Set.__repr__
      ~abjad.tools.pitchtools.Set.Set.Set.__str__
      ~abjad.tools.pitchtools.Set.Set.Set.__sub__
      ~abjad.tools.pitchtools.Set.Set.Set.__xor__

Bases
-----

- :py:class:`datastructuretools.TypedFrozenset <abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.TypedFrozenset>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.Set.Set.Set.item_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Set.Set.Set.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.pitchtools.Set.Set.Set.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.from_selection
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.intersection
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.isdisjoint
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.issubset
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.issuperset
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.new
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.union
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__sub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Set.Set.Set.__xor__
   :noindex:
